@@ -45,8 +45,8 @@
  * be run as an arbitrary non-root user, as above.
  *
  * Certain tests can usefully be run again, as root. When this is done,
- * tests using TEST_USER_ROOT, TEST_USER_MESSAGEBUS and/or TEST_USER_OTHER
- * can exercise situations that only arise when there's more than one uid.
+ * tests using a TestUser other than TEST_USER_ME can exercise situations
+ * that only arise when there's more than one uid.
  */
 typedef enum {
     /* Whatever user happens to be running the regression test;
@@ -58,6 +58,11 @@ typedef enum {
      * from configure.ac, usually 'messagebus' but perhaps 'dbus' or
      * '_dbus'. */
     TEST_USER_MESSAGEBUS,
+    /* Run as uid 0, expecting to drop privileges to the user who would
+     * normally run the system bus (so we must skip the test if that user
+     * doesn't exist). Only valid for test_get_dbus_daemon(), not for
+     * test_connect_to_bus_as_user(). */
+    TEST_USER_ROOT_DROP_TO_MESSAGEBUS,
     /* An unprivileged user who is neither root nor DBUS_USER.
      * This is DBUS_TEST_USER from configure.ac, usually 'nobody'. */
     TEST_USER_OTHER
@@ -121,11 +126,24 @@ backported_g_steal_pointer (gpointer pointer_to_pointer)
 }
 #endif
 
+#ifndef g_assert_true
+#define g_assert_true(a) g_assert (a)
+#endif
+
+#ifndef g_assert_false
+#define g_assert_false(a) g_assert (!(a))
+#endif
+
+#ifndef g_assert_null
+#define g_assert_null(a) g_assert ((a) == NULL)
+#endif
+
 #ifndef g_assert_nonnull
-#define g_assert_nonnull(a) g_assert (a != NULL)
+#define g_assert_nonnull(a) g_assert ((a) != NULL)
 #endif
 
 gboolean test_check_tcp_works (void);
+gboolean test_check_af_unix_works (void);
 
 void test_store_result_cb (GObject *source_object,
                            GAsyncResult *result,
